( cd opt/kde/share/doc/HTML/nl/kivio ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kivio ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kword ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/koffice ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/koshell ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kspread ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kpresenter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/thesaurus ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
( cd opt/kde/share/doc/HTML/nl/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/nl/kformula ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
